# CharCountPy

CharCountPy is a Python package for counting single characters in a given text.
Use lonely_characters_counter function to count single characters

## Installation

You can install CharCountPy using pip:

```bash
pip install charcountpy